import React, { useEffect, useState } from "react";
import { Card } from "./Card/Card";
import { useFetchZones } from "../../hooks/useFetchZones";
import { Flight } from "../../Types";
import { useNavigate } from "react-router";
import useAuth from "../../useAuth";

interface Props {
	flights?: Flight[];
}

export const Home: React.FC<Props> = (props) => {
    const urlParams = new URLSearchParams(window.location.search);
    const origin = urlParams.get('origin');
	const { zones, error } = useFetchZones(origin);
    const navigate = useNavigate()

    const { loading, isAirline } = useAuth();

    if (loading) {
        return <div>Loading...</div>;
    }

	return (
		<div className="Box">
            {isAirline ? <button onClick={() => { console.log("ANA"); navigate("/create-flight") }}>CREATE FLIGHT</button> : <></>}
			<h2>Flights</h2>
			<div className="Items">
					{(props.flights ? props.flights : zones).map((u) => {
						return <Card key={u.id} flight={u} />;
					})}
				{error ? <div className="Disconnected">{error}</div> : <></>}
			</div>
		</div>
	);
};
